@@ -2,7 +2,10 @@ __all__ = ["main"]
 
 import getpass
 import os
+import platform
 from argparse import ArgumentParser, Namespace
+from datetime import datetime
+from json import dumps
 
 import requests.exceptions
 
@@ -40,6 +43,21 @@ def main() -> None:
         f._error("The team specified is not in the configuration, please authenticate first.")
     except requests.exceptions.ConnectionError:
         f._error("Darwin seems unreachable, please try again in a minute or contact support.")
+    except Exception as e:  # Catch unhandled exceptions
+        filename = f"darwin_error_{datetime.now().timestamp()}.log"
+
+        fd = open(filename, "w")
+        fd.write("Darwin CLI error log")
+        fd.write(f"Version: {__version__}")
+        fd.write(f"OS: {platform.platform()}")
+        fd.write(f"Command: {dumps(args, check_circular=True)}")
+        fd.write(f"Error: {dumps(e, check_circular=True)}")
+        fd.close()
+
+        f._error(
+            "An unexpected error occurred, errors have been written to {filename}, please contact support, and send them the file."
+            + str(e)
+        )
 
 
 def _run(args: Namespace, parser: ArgumentParser) -> None:
