@@ -35,7 +35,17 @@ if TYPE_CHECKING:
 
 
 SUPPORTED_IMAGE_EXTENSIONS = [".png", ".jpeg", ".jpg", ".jfif", ".tif", ".tiff", ".bmp", ".svs", ".webp"]
-SUPPORTED_VIDEO_EXTENSIONS = [".avi", ".bpm", ".dcm", ".mov", ".mp4", ".pdf", ".ndpi"]
+SUPPORTED_VIDEO_EXTENSIONS = [
+    ".avi",
+    ".bpm",
+    ".dcm",
+    ".mov",
+    ".mp4",
+    ".pdf",
+    ".nii",
+    ".nii.gz",
+    ".ndpi",
+]
 SUPPORTED_EXTENSIONS = SUPPORTED_IMAGE_EXTENSIONS + SUPPORTED_VIDEO_EXTENSIONS
 
 
@@ -200,8 +210,8 @@ def find_files(
     for f in files:
         path = Path(f)
         if path.is_dir():
-            found_files.extend([f for f in path.glob(pattern) if is_extension_allowed(f.suffix) and not f.is_dir()])
-        elif is_extension_allowed(path.suffix):
+            found_files.extend([f for f in path.glob(pattern) if is_extension_allowed("".join(f.suffixes))])
+        elif is_extension_allowed("".join(path.suffixes)):
             found_files.append(path)
         else:
             raise UnsupportedFileType(path)
@@ -257,7 +267,10 @@ def persist_client_configuration(
 
 
 def _get_local_filename(metadata: Dict[str, Any]) -> str:
-    return metadata["filename"]
+    if "original_filename" in metadata:
+        return metadata["original_filename"]
+    else:
+        return metadata["filename"]
 
 
 def parse_darwin_json(path: Path, count: Optional[int]) -> Optional[dt.AnnotationFile]:
@@ -359,6 +372,7 @@ def _parse_darwin_slot(data: Dict[str, Any]) -> dt.Slot:
         frame_count=data.get("frame_count"),
         frame_urls=data.get("frame_urls"),
         fps=data.get("fps"),
+        metadata=data.get("metadata"),
     )
 
 
@@ -373,23 +387,24 @@ def _parse_darwin_image(path: Path, data: Dict[str, Any], count: Optional[int])
         thumbnail_url=data["image"].get("thumbnail_url"),
         width=data["image"].get("width"),
         height=data["image"].get("height"),
+        metadata=data["image"].get("metadata"),
     )
 
     annotation_file = dt.AnnotationFile(
-        path,
-        _get_local_filename(data["image"]),
-        annotation_classes,
-        annotations,
-        False,
-        data["image"].get("width"),
-        data["image"].get("height"),
-        data["image"].get("url"),
-        data["image"].get("workview_url"),
-        data["image"].get("seq", count),
-        None,
-        data["image"].get("path", "/"),
-        [],
-        data["image"].get("thumbnail_url"),
+        path=path,
+        filename=_get_local_filename(data["image"]),
+        annotation_classes=annotation_classes,
+        annotations=annotations,
+        is_video=False,
+        image_width=data["image"].get("width"),
+        image_height=data["image"].get("height"),
+        image_url=data["image"].get("url"),
+        workview_url=data["image"].get("workview_url"),
+        seq=data["image"].get("seq", count),
+        frame_urls=None,
+        remote_path=data["image"].get("path", "/"),
+        slots=[],
+        image_thumbnail_url=data["image"].get("thumbnail_url"),
     )
     annotation_file.slots.append(slot)
     return annotation_file
@@ -412,23 +427,23 @@ def _parse_darwin_video(path: Path, data: Dict[str, Any], count: Optional[int])
         frame_count=data["image"].get("frame_count"),
         frame_urls=data["image"].get("frame_urls"),
         fps=data["image"].get("fps"),
+        metadata=data["image"].get("metadata"),
     )
-
     annotation_file = dt.AnnotationFile(
-        path,
-        _get_local_filename(data["image"]),
-        annotation_classes,
-        annotations,
-        True,
-        data["image"].get("width"),
-        data["image"].get("height"),
-        data["image"].get("url"),
-        data["image"].get("workview_url"),
-        data["image"].get("seq", count),
-        data["image"].get("frame_urls"),
-        data["image"].get("path", "/"),
-        [],
-        data["image"].get("thumbnail_url"),
+        path=path,
+        filename=_get_local_filename(data["image"]),
+        annotation_classes=annotation_classes,
+        annotations=annotations,
+        is_video=True,
+        image_width=data["image"].get("width"),
+        image_height=data["image"].get("height"),
+        image_url=data["image"].get("url"),
+        workview_url=data["image"].get("workview_url"),
+        seq=data["image"].get("seq", count),
+        frame_urls=data["image"].get("frame_urls"),
+        remote_path=data["image"].get("path", "/"),
+        slots=[],
+        image_thumbnail_url=data["image"].get("thumbnail_url"),
     )
     annotation_file.slots.append(slot)
 
@@ -539,7 +554,6 @@ def _parse_darwin_video_annotation(annotation: dict) -> Optional[dt.VideoAnnotat
 
     if not frame_annotations:
         return None
-
     main_annotation = dt.make_video_annotation(
         frame_annotations,
         keyframes,
@@ -595,7 +609,6 @@ def split_video_annotation(annotation: dt.AnnotationFile) -> List[dt.AnnotationF
         ]
         annotation_classes: Set[dt.AnnotationClass] = set([annotation.annotation_class for annotation in annotations])
         filename: str = f"{Path(annotation.filename).stem}/{i:07d}.png"
-
         frame_annotations.append(
             dt.AnnotationFile(
                 annotation.path,
@@ -608,6 +621,7 @@ def split_video_annotation(annotation: dt.AnnotationFile) -> List[dt.AnnotationF
                 frame_url,
                 annotation.workview_url,
                 annotation.seq,
+                slots=annotation.slots,
             )
         )
     return frame_annotations
@@ -912,7 +926,6 @@ def _parse_version(data) -> dt.AnnotationFileVersion:
 def _data_to_annotations(data: Dict[str, Any]) -> List[Union[dt.Annotation, dt.VideoAnnotation]]:
     raw_image_annotations = filter(lambda annotation: "frames" not in annotation, data["annotations"])
     raw_video_annotations = filter(lambda annotation: "frames" in annotation, data["annotations"])
-
     image_annotations: List[dt.Annotation] = list(filter(None, map(_parse_darwin_annotation, raw_image_annotations)))
     video_annotations: List[dt.VideoAnnotation] = list(
         filter(None, map(_parse_darwin_video_annotation, raw_video_annotations))
